@@ -22,7 +22,11 @@ pub enum Token {
         raw: JsWord,
     },
 
-    // TODO: Function
+    Function {
+        value: JsWord,
+        raw: JsWord,
+    },
+
     /// `@`
     AtKeyword {
         value: JsWord,
@@ -66,9 +70,18 @@ pub enum Token {
         raw: JsWord,
     },
 
-    // TODO Percentage
+    Percent {
+        value: f64,
+        raw: JsWord,
+    },
+
+    Dimension {
+        value: f64,
+        raw_value: JsWord,
+        unit: JsWord,
+        raw_unit: JsWord,
+    },
 
-    // TODO dimension
     /// One or more whitespace.
     WhiteSpace,
 
